@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Cwd 'realpath';
 
-our $VERSION   = '1.3051';
+our $VERSION   = '1.3060';
 our $AUTHORITY = 'SUKRIA';
 
 use Dancer::App;
@@ -36,6 +36,7 @@ our @EXPORT    = qw(
   any
   before
   before_template
+  cookie
   cookies
   config
   content_type
@@ -61,8 +62,8 @@ our @EXPORT    = qw(
   load_app
   logger
   mime
-  mime_type
   options
+  param
   params
   pass
   path
@@ -103,6 +104,7 @@ sub any             { Dancer::App->current->registry->any_add(@_) }
 sub before          { Dancer::Hook->new('before', @_) }
 sub before_template { Dancer::Hook->new('before_template', @_) }
 sub captures        { Dancer::SharedData->request->params->{captures} }
+sub cookie          { Dancer::Cookies->cookie( @_ ) }
 sub cookies         { Dancer::Cookies->cookies }
 sub config          { Dancer::Config::settings() }
 sub content_type    { Dancer::SharedData->response->content_type(@_) }
@@ -136,11 +138,9 @@ sub logger          {
     set(logger => @_)
 }
 sub mime            { Dancer::MIME->instance() }
-sub mime_type       {
-    Dancer::Deprecation->deprecated(reason => "use 'mime' from Dancer.pm",fatal => 1)
-}
 sub options         { Dancer::App->current->registry->universal_add('options', @_) }
 sub params          { Dancer::SharedData->request->params(@_) }
+sub param           { params->{$_[0]} }
 sub pass            { Dancer::SharedData->response->pass(1) }
 sub path            { realpath(Dancer::FileUtils::path(@_)) }
 sub post            { Dancer::App->current->registry->universal_add('post', @_) }
@@ -288,6 +288,7 @@ sub _init_script_dir {
     $res or croak "unable to set libdir : $error";
 }
 
+
 # Scheme grammar as defined in RFC 2396
 #  scheme = alpha *( alpha | digit | "+" | "-" | "." )
 my $scheme_re = qr{ [a-z][a-z0-9\+\-\.]* }ix;
@@ -367,7 +368,7 @@ Dancer - lightweight yet powerful web application framework
     use Dancer;
 
     get '/hello/:name' => sub {
-        return "Why, hello there " . params->{name};
+        return "Why, hello there " . param('name');
     };
 
     dance;
@@ -556,6 +557,17 @@ In the case you have stored something else than a Scalar in your cookie:
         return ($values{token}, $values{token_secret});
     };
 
+
+=head2 cookie
+
+Accesses a cookie value (ot set it). Note that this method will
+eventually be preferred to C<set_cookie>.
+
+    cookie lang => "fr-FR";              # set a cookie and return its value
+    cookie lang => "fr-FR", expires => "2 hours";   # extra cookie info
+    cookie "lang"                        # return a cookie value
+
+
 =head2 config
 
 Accesses the configuration of the application:
@@ -571,7 +583,7 @@ Sets the B<content-type> rendered, for the current route handler:
     get '/cat/:txtfile' => sub {
         content_type 'text/plain';
 
-        # here we can dump the contents of params->{txtfile}
+        # here we can dump the contents of param('txtfile')
     };
 
 You can use abbreviations for content types. For instance:
@@ -579,7 +591,7 @@ You can use abbreviations for content types. For instance:
     get '/svg/:id' => sub {
         content_type 'svg';
 
-        # here we can dump the image with id params->{id}
+        # here we can dump the image with id param('id')
     };
 
 Note that if you want to change the default content-type for every route, you
@@ -770,7 +782,7 @@ Supported B<before> hooks (in order of execution):
 
 This hook receives no arguments.
 
-  hook before_deserializer {
+  hook before_deserializer => sub {
     ...
   };
 
@@ -778,7 +790,7 @@ This hook receives no arguments.
 
 This hook receives as argument the path of the file to render.
 
-  hook before_file_render {
+  hook before_file_render => sub {
     my $path = shift;
     ...
   };
@@ -803,7 +815,7 @@ This hook receives no arguments.
 
 is equivalent to
 
-  hook before sub {
+  hook before => sub {
     ...
   };
 
@@ -813,14 +825,14 @@ This is an alias to 'before_template'.
 
 This hook receives as argument a HashRef, containing the tokens.
 
-  hook before_template_render sub {
+  hook before_template_render => sub {
     my $tokens = shift;
     delete $tokens->{user};
   };
 
 is equivalent to 
 
-  hook before_template sub {
+  hook before_template => sub {
     my $tokens = shift;
     delete $tokens->{user};
   };
@@ -830,7 +842,7 @@ is equivalent to
 This hook receives two arguments. The first one is a HashRef containing the
 tokens. The second is a ScalarRef representing the content of the template.
 
-  hook before_layout_render sub {
+  hook before_layout_render => sub {
     my ($tokens, $html_ref) = @_;
     ...
   };
@@ -839,7 +851,7 @@ tokens. The second is a ScalarRef representing the content of the template.
 
 This hook receives as argument a L<Dancer::Response> object.
 
-  hook before_serializer sub {
+  hook before_serializer => sub {
     my $response = shift;
     $response->content->{start_time} = time();
   };
@@ -854,7 +866,7 @@ Supported B<after> hooks (in order of execution):
 
 This hook receives no arguments.
 
-  hook after_deserializer sub {
+  hook after_deserializer => sub {
     ...
   };
 
@@ -862,7 +874,7 @@ This hook receives no arguments.
 
 This hook receives as argument a L<Dancer::Response> object.
 
-  hook after_file_render sub {
+  hook after_file_render => sub {
     my $response = shift;
   };
 
@@ -871,7 +883,7 @@ This hook receives as argument a L<Dancer::Response> object.
 This hook receives as argument a ScalarRef representing the content generated
 by the template.
 
-  hook after_template_render sub {
+  hook after_template_render => sub {
     my $html_ref = shift;
   };
 
@@ -880,7 +892,7 @@ by the template.
 This hook receives as argument a ScalarRef representing the content generated
 by the layout
 
-  hook after_layout_render sub {
+  hook after_layout_render => sub {
     my $html_ref = shift;
   };
 
@@ -890,7 +902,7 @@ This is an alias for 'after'.
 
 This hook receives as argument a L<Dancer::Response> object.
 
-  hook after sub {
+  hook after => sub {
     my $response = shift;
   };
 
@@ -971,7 +983,20 @@ commonly-used methods are summarized below:
 =head2 params
 
 I<This method should be called from a route handler>.
-It's an alias for the L<Dancer::Request params accessor|Dancer::Request/"params">.
+It's an alias for the L<Dancer::Request params accessor|Dancer::Request/"params">. It returns
+an hash reference to all defined parameters. Check C<param> bellow to access quickly to a single
+parameter value.
+
+=head2 param
+
+I<This method should be called from a route handler>.
+This method is an accessor to the parameters hash table.
+
+   post '/login' => sub {
+       my $username = param "user";
+       my $password = param "pass";
+       # ...
+   }
 
 =head2 pass
 
@@ -1018,6 +1043,16 @@ You can unset the prefix value:
     prefix undef;
     get '/page1' => sub {}; will match /page1
 
+For a safer alternative you can use lexical prefix like this:
+
+    prefix '/home' => sub {
+        ## Prefix is set to '/home' here
+        
+        get ...;
+        get ...;
+    };
+    ## prefix reset to the previous version here
+
 B<Notice:> once you have a prefix set, do not add a caret to the regex:
 
     prefix '/foo';
@@ -1118,7 +1153,7 @@ saying C<return send_error(...)> instead.
 
 Lets the current route handler send a file to the client. Note that
 the path of the file must be relative to the B<public> directory unless you use
-the C<absolute> option (see below).
+the C<system_path> option (see below).
 
     get '/download/:file' => sub {
         send_file(params->{file});
@@ -1186,6 +1221,9 @@ should be Scalars; storing references will not work.
 
 See L<Dancer::Cookie> for further options when creating your cookie.
 
+Note that this method will be eventually deprecated in favor of the
+new C<cookie> method.
+
 =head2 session
 
 Provides access to all data stored in the user's session (if any).
@@ -1217,6 +1255,11 @@ You may also need to clear a session:
         ...
     };
 
+If you need to fetch the session ID being used for any reason:
+
+    my $id = session->id;
+
+
 =head2 splat
 
 Returns the list of captures made from a route handler with a route pattern
@@ -1427,7 +1470,11 @@ see the AUTHORS file that comes with this distribution for details.
 =head1 SOURCE CODE
 
 The source code for this module is hosted on GitHub
-L<http://github.com/sukria/Dancer>
+L<http://github.com/sukria/Dancer>.  Feel free to fork the repository and submit
+pull requests!  (See L<Dancer::Development> for details on how to contribute).
+
+Also, why not L<watch the repo|https://github.com/sukria/Dancer/toggle_watch> to
+keep up to date with the latest upcoming changes?
 
 
 =head1 GETTING HELP / CONTRIBUTING
