@@ -29,10 +29,17 @@ sub set_running_app {
 }
 
 sub set_prefix {
-    my ($self, $prefix) = @_;
+    my ($self, $prefix, $cb) = @_;
     croak "not a valid prefix: `$prefix', must start with a /"
       if defined($prefix) && $prefix !~ /^\//;
+    my $previous = Dancer::App->current->prefix;
     Dancer::App->current->prefix($prefix);
+    if (ref($cb) eq 'CODE') {
+        eval { $cb->() };
+        my $e = $@;
+        Dancer::App->current->prefix($previous);
+        die $e if $e;
+    }
     return 1;    # prefix may have been set to undef
 }
 
@@ -163,21 +170,33 @@ sub get {
 }
 
 sub setting {
-    my ($self, $name, $value) = @_;
+    my $self = shift;
 
     if ($self->name eq 'main') {
-        return (@_ == 3)
-          ? Dancer::Config::setting($name => $value)
-          : Dancer::Config::setting($name);
+        return (@_ > 1)
+          ? Dancer::Config::setting( @_ )
+          : Dancer::Config::setting( $_[0] );
     }
 
-    return
-      (@_ == 3) ? $self->settings->{$name} =
-      Dancer::Config->normalize_setting($name => $value)
-      : (
+    if (@_ > 1) {
+        $self->_set_settings(@_)
+    } else {
+        my $name = shift;
         exists($self->settings->{$name}) ? $self->settings->{$name}
-        : Dancer::Config::setting($name)
-      );
+          : Dancer::Config::setting($name);
+    }
 }
 
+sub _set_settings {
+    my $self = shift;
+    die "Odd number of elements in set" unless @_ % 2 == 0;
+    while (@_) {
+        my $name = shift;
+        my $value = shift;
+        $self->settings->{$name} =
+          Dancer::Config->normalize_setting($name => $value);
+    }
+}
+
+
 1;
