@@ -16,6 +16,14 @@ sub init {
     $COOKIES = parse_cookie_from_env();
 }
 
+sub cookie {
+    my $class = shift;
+    my $name  = shift;
+    my $value = shift;
+    defined $value && set_cookie( $class, $name, $value, @_ );
+    cookies->{$name} ? cookies->{$name}->value : undef;
+}
+
 sub parse_cookie_from_env {
     my $request = Dancer::SharedData->request;
     my $env     = (defined $request) ? $request->env : {};
@@ -76,6 +84,11 @@ Dancer::Cookies - a singleton storage for all cookies
         print "$name => $value\n";
     }
 
+
+    cookie lang => "fr-FR"; #set a cookie and return its value
+    cookie lang => "fr-FR", expires => "2 hours";
+    cookie "lang"           #return a cookie value
+
 =head1 DESCRIPTION
 
 Dancer::Cookies keeps all the cookies defined by the application and makes them
@@ -96,6 +109,14 @@ Returns a hash reference of all cookies, all objects of L<Dancer::Cookie> type.
 
 The key is the cookie name, the value is the L<Dancer::Cookie> object.
 
+=head2 cookie
+
+C<cookie> method is useful to query or set cookies easily.
+
+    cookie lang => "fr-FR";              # set a cookie and return its value
+    cookie lang => "fr-FR", expires => "2 hours";   # extra cookie info
+    cookie "lang"                        # return a cookie value
+
 =head2 parse_cookie_from_env
 
 Fetches all the cookies from the environment, parses them and creates a hashref
