@@ -1,8 +1,5 @@
 package Dancer::Hook;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: Class to manipulate hooks with Dancer
-$Dancer::Hook::VERSION = '1.3514_04'; # TRIAL
-$Dancer::Hook::VERSION = '1.351404';
+
 use strict;
 use warnings;
 use Carp;
@@ -13,7 +10,6 @@ __PACKAGE__->attributes(qw/name code properties/);
 
 use Dancer::Factory::Hook;
 use Dancer::Hook::Properties;
-use Dancer::Exception qw(:all);
 
 sub new {
     my ($class, @args) = @_;
@@ -21,7 +17,7 @@ sub new {
     my $self = bless {}, $class;
 
     if (!scalar @args) {
-        raise core_hook => "one name and a coderef are required";
+        croak "one name and a coderef are required";
     }
 
     my $hook_name = shift @args;
@@ -45,23 +41,26 @@ sub new {
         $code       = shift @args;
     }
     else {
-        raise core_hook => "something's wrong with parameters passed to Hook constructor";
+        croak "something's wrong";
     }
-    ref $code eq 'CODE'
-      or raise core_hook => "the code argument passed to hook construction was not a CodeRef. Value was : '$code'";
-
 
     my $compiled_filter = sub {
-        my @arguments = @_;
         return if Dancer::SharedData->response->halted;
 
         my $app = Dancer::App->current();
         return unless $properties->should_run_this_app($app->name);
 
         Dancer::Logger::core( "entering " . $hook_name . " hook" );
+        eval { $code->(@_) };
 
-        $code->(@arguments);
-
+        if ($@) {
+            my $err = Dancer::Error->new(
+                code    => 500,
+                title   => $hook_name . ' filter error',
+                message => "An error occured while executing the filter named $hook_name: $@"
+            );
+            return Dancer::halt( $err->render );
+        }
     };
 
     $self->properties($properties);
@@ -73,19 +72,13 @@ sub new {
 
 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Hook - Class to manipulate hooks with Dancer
 
-=head1 VERSION
+=head1 DESCRIPTION
 
-version 1.3514_04
+Manipulate hooks with Dancer
 
 =head1 SYNOPSIS
 
@@ -93,10 +86,6 @@ version 1.3514_04
   use Dancer::Hook;
   Dancer::Hook->register_hooks_name(qw/before_auth after_auth/);
 
-=head1 DESCRIPTION
-
-Manipulate hooks with Dancer
-
 =head1 METHODS
 
 =head2 register_hook ($hook_name, [$properties], $code)
@@ -104,7 +93,7 @@ Manipulate hooks with Dancer
     hook 'before', {apps => ['main']}, sub {...};
 
     hook 'before' => sub {...};
-
+    
 Attaches a hook at some point, with a possible list of properties.
 
 Currently supported properties:
@@ -119,7 +108,7 @@ Currently supported properties:
 
 =head2 register_hooks_name
 
-Add a new hook name, so application developers can insert some code at this point.
+Add a new hook name, so developpers of application can insert some code at this point.
 
     package My::Dancer::Plugin;
     Dancer::Hook->instance->register_hooks_name(qw/before_auth after_auth/);
@@ -144,16 +133,3 @@ This module has been written by Alexis Sukrieh and others.
 
 This module is free software and is published under the same
 terms as Perl itself.
-
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
