@@ -3,10 +3,18 @@ package Dancer::Template::Abstract;
 use strict;
 use warnings;
 use Carp;
+
+use Dancer::Factory::Hook;
+use Dancer::Deprecation;
 use Dancer::FileUtils 'path';
+
 use base 'Dancer::Engine';
 
-# Overloads this method to implement the rendering
+Dancer::Factory::Hook->instance->install_hooks(
+    qw/before_template_render after_template_render before_layout_render after_layout_render/
+);
+
+# overloads this method to implement the rendering
 # args:   $self, $template, $tokens
 # return: a string of $template's content processed with $tokens
 sub render { confess "render not implemented" }
@@ -46,12 +54,13 @@ sub apply_renderer {
     ($tokens, undef) = _prepare_tokens_options($tokens);
 
     $view = $self->view($view);
-    -r $view or return;
 
-    $_->($tokens) for (@{Dancer::App->current->registry->hooks->{before_template}});
+    Dancer::Factory::Hook->execute_hooks('before_template_render', $tokens);
 
     my $content = $self->render($view, $tokens);
 
+    Dancer::Factory::Hook->execute_hooks('after_template_render', \$content);
+
     # make sure to avoid ( undef ) in list context return
     defined $content
       and return $content;
@@ -76,8 +85,13 @@ sub apply_layout {
 
     defined $layout or return $content;
 
+    Dancer::Factory::Hook->execute_hooks('before_layout_render', $tokens, \$content);
+
     my $full_content =
       $self->layout($layout, $tokens, $content);
+
+    Dancer::Factory::Hook->execute_hooks('after_layout_render', \$full_content);
+
     # make sure to avoid ( undef ) in list context return
     defined $full_content
       and return $full_content;
@@ -91,10 +105,12 @@ sub _prepare_tokens_options {
 
     # these are the default tokens provided for template processing
     $tokens ||= {};
+    $tokens->{perl_version}   = $];
     $tokens->{dancer_version} = $Dancer::VERSION;
     $tokens->{settings}       = Dancer::Config->settings;
     $tokens->{request}        = Dancer::SharedData->request;
     $tokens->{params}         = Dancer::SharedData->request->params;
+    $tokens->{vars}           = Dancer::SharedData->vars;
 
     Dancer::App->current->setting('session')
       and $tokens->{session} = Dancer::Session->get;
@@ -102,6 +118,41 @@ sub _prepare_tokens_options {
     return ($tokens, $options);
 }
 
+sub _render_with_layout {
+    my ($class, $content, $tokens, $options) = @_;
+
+    Dancer::Deprecation::deprecated(
+        feature => 'render_with_layout',
+        version => '1.3000',
+        fatal   => 1,
+        reason  => "use the 'engine' keyword to get the template engine, and use 'apply_layout' on the result",
+    );
+}
+
+sub template {
+    my ($class, $view, $tokens, $options) = @_;
+    my ($content, $full_content);
+
+    # it's important that $tokens is not undef, so that things added to it via
+    # a before_template in apply_renderer survive to the apply_layout. GH#354
+    $tokens  ||= {};
+    $options ||= {};
+
+    $content = $view ? Dancer::Template->engine->apply_renderer($view, $tokens)
+                     : delete $options->{content};
+
+    defined $content and $full_content =
+      Dancer::Template->engine->apply_layout($content, $tokens, $options);
+
+    defined $full_content
+      and return $full_content;
+
+    Dancer::Error->new(
+        code    => 404,
+        message => "Page not found",
+    )->render();
+}
+
 1;
 __END__
 
