@@ -122,6 +122,11 @@ sub route_doesnt_exist {
 # Response status
 
 sub response_exists {
+    Dancer::Deprecation->deprecated(
+       fatal   => 0,
+       feature => 'response_exists',
+       reason  => 'Use response_status_isnt and check for status 404.'
+    );
     my ($req, $test_name) = @_;
 
     $test_name ||= "a response is found for " . _req_label($req);
@@ -135,6 +140,11 @@ sub response_exists {
 }
 
 sub response_doesnt_exist {
+    Dancer::Deprecation->deprecated(
+       fatal   => 0,
+       feature => 'response_doesnt_exist',
+       reason  => 'Use response_status_is and check for status 404.',
+    );
     my ($req, $test_name) = @_;
 
     $test_name ||= "no response found for " . _req_label($req);
@@ -277,7 +287,7 @@ sub dancer_response {
         if ( $args->{body} ) {
             $content      = $args->{body};
             $content_type = $args->{content_type}
-              || 'application/x-www-form-data';
+                || 'application/x-www-form-urlencoded';
 
             # coerce hashref into an url-encoded string
             if ( ref($content) && ( ref($content) eq 'HASH' ) ) {
@@ -313,7 +323,7 @@ Content-Type: text/plain
         $l = length $content if defined $content;
         open my $in, '<', \$content;
         $ENV{'CONTENT_LENGTH'} = $l;
-        $ENV{'CONTENT_TYPE'}   = $content_type;
+        $ENV{'CONTENT_TYPE'}   = $content_type || "";
         $ENV{'psgi.input'}     = $in;
     }
 
